<?php

namespace App\Http\Controllers\User;

use Alert;
use App\Http\Controllers\Controller;
use App\Repositories\User\StafPendukungRepository;
use App\Repositories\Admin\MsTingkatPendidikanRepository;
use App\Repositories\Admin\MsUnitKerjaRepository;
use App\Repositories\Admin\MsJabatanRepository;
use Crypt;
use Illuminate\Http\Request;

class StafPendukungController extends Controller
{
    private $stafpendukungRepo;
    private $msunitkerjaRepo;
    private $mstingkatpendidikanRepo;
    private $msjabatanRepo;

    public function __construct(
        StafPendukungRepository $stafpendukungRepo,
        MsUnitKerjaRepository $msunitkerjaRepo,
        MsTingkatPendidikanRepository $mstingkatpendidikanRepo,
        MsJabatanRepository $msjabatanRepo
    ){
        $this->stafpendukungRepo = $stafpendukungRepo;
        $this->msunitkerjaRepo = $msunitkerjaRepo;
        $this->mstingkatpendidikanRepo = $mstingkatpendidikanRepo;
        $this->msjabatanRepo = $msjabatanRepo;
    }
    public function index()
    {
        //
        $menu = 'stafpendukung';
        $stafpendukung = $this->stafpendukungRepo->get(['rUnitkerja','rTingkatpendidikan','rJabatan']);

        $data = [
            'stafpendukung' => $stafpendukung,
            'menu' => $menu
        ];

        return view('user.stafpendukung.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $menu='stafpendukung';
        $unitkerja = $this->msunitkerjaRepo->get()->pluck('nama', 'kode');
        $tingkatpendidikan = $this->mstingkatpendidikanRepo->get()->pluck('nama', 'kode');
        $jabatan = $this->msjabatanRepo->get()->pluck('nama', 'kode');
       // dd($unitkerja);
        $data = [
            'unitkerja' => $unitkerja,
            'tingkatpendidikan' => $tingkatpendidikan,
            'jabatan' => $jabatan,
            'menu' => $menu
        ];

        return view('user.stafpendukung.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $data = $request->except('_token');
        $data['user_id'] = auth()->user()->id;
        $stafpendukung = $this->stafpendukungRepo->store($data);

        $data = [
            'stafpendukung' => $stafpendukung->id,
        ];

        Alert::success('Berhasil', 'Kontrak Kerja berhasil disimpan');

        return redirect()->route('stafpendukung.index', $data);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        $menu = 'stafpendukung';
        $unitkerja = $this->msunitkerjaRepo->get()->pluck('nama', 'kode');
        $tingkatpendidikan = $this->mstingkatpendidikanRepo->get()->pluck('nama', 'kode');
        $jabatan = $this->msjabatanRepo->get()->pluck('nama', 'kode');
        $stafpendukung = $this->stafpendukungRepo->findId(null, $id);

        $data = [

            'menu' => $menu,
            'unitkerja' => $unitkerja,
            'tingkatpendidikan' => $tingkatpendidikan,
            'jabatan' => $jabatan,
            'stafpendukung' => $stafpendukung,
        ];

        return view('user.stafpendukung.edit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        $data = $request->except('_token');
        $data['userid_updated'] = auth()->user()->id;
        $stafpendukung = $this->stafpendukungRepo->findId(null, $id);
        $this->stafpendukungRepo->update($data, $stafpendukung);

        $data = [
            'stafpendukung' => $stafpendukung->id,
        ];

        Alert::success('Berhasil', 'Staf Pendukung berhasil diupdated');

        return redirect()->route('stafpendukung.index', $data);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
        $model = $this->stafpendukungRepo->findId(null, Crypt::decrypt($id));
        $this->stafpendukungRepo->destroy($model);

        Alert::success('Data berhasil dihapus')->persistent('Ok');

        return redirect()->route('stafpendukung.index');
    }
}
